@@ -884,7 +884,9 @@ def literal_schema(
         metadata: See [TODO] for details
         serialization: Custom serialization schema
     """
-    return dict_not_none(type='literal', expected=expected, ref=ref, metadata=metadata, serialization=serialization)
+    return dict_not_none(
+        type='literal', expected=list(expected), ref=ref, metadata=metadata, serialization=serialization
+    )
 
 
 # must match input/parse_json.rs::JsonType::try_from
@@ -1134,7 +1136,7 @@ def tuple_positional_schema(
     return dict_not_none(
         type='tuple',
         mode='positional',
-        items_schema=items_schema,
+        items_schema=list(items_schema),
         extra_schema=extra_schema,
         strict=strict,
         ref=ref,
@@ -1795,7 +1797,7 @@ def union_schema(
     """
     return dict_not_none(
         type='union',
-        choices=choices,
+        choices=list(choices),
         auto_collapse=auto_collapse,
         custom_error_type=custom_error_type,
         custom_error_message=custom_error_message,
@@ -1811,7 +1813,7 @@ class TaggedUnionSchema(TypedDict, total=False):
     type: Required[Literal['tagged-union']]
     choices: Required[Dict[Union[str, int], Union[str, int, CoreSchema]]]
     discriminator: Required[
-        Union[str, List[Union[str, int]], List[List[Union[str, int]]], Callable[[Any], Optional[str]]]
+        Union[str, List[Union[str, int]], List[List[Union[str, int]]], Callable[[Any], Optional[Union[str, int]]]]
     ]
     custom_error_type: str
     custom_error_message: str
@@ -1825,7 +1827,7 @@ class TaggedUnionSchema(TypedDict, total=False):
 
 def tagged_union_schema(
     choices: Dict[Union[int, str], int | str | CoreSchema],
-    discriminator: str | list[str | int] | list[list[str | int]] | Callable[[Any], str | None],
+    discriminator: str | list[str | int] | list[list[str | int]] | Callable[[Any], str | int | None],
     *,
     custom_error_type: str | None = None,
     custom_error_message: str | None = None,
@@ -1874,7 +1876,8 @@ def tagged_union_schema(
             * If `discriminator` is a str, it is the name of the attribute to use as the discriminator
             * If `discriminator` is a list of int/str, it should be used as a "path" to access the discriminator
             * If `discriminator` is a list of lists, each inner list is a path, and the first path that exists is used
-            * If `discriminator` is a callable, it should return the discriminator when called on the value to validate
+            * If `discriminator` is a callable, it should return the discriminator when called on the value to validate;
+              the callable can return `None` to indicate that there is no matching discriminator present on the input
         custom_error_type: The custom error type to use if the validation fails
         custom_error_message: The custom error message to use if the validation fails
         custom_error_context: The custom error context to use if the validation fails
@@ -1932,7 +1935,7 @@ def chain_schema(
         metadata: See [TODO] for details
         serialization: Custom serialization schema
     """
-    return dict_not_none(type='chain', steps=steps, ref=ref, metadata=metadata, serialization=serialization)
+    return dict_not_none(type='chain', steps=list(steps), ref=ref, metadata=metadata, serialization=serialization)
 
 
 class LaxOrStrictSchema(TypedDict, total=False):
@@ -2026,7 +2029,9 @@ def typed_dict_field(
     Args:
         schema: The schema to use for the field
         required: Whether the field is required
-        alias: The alias(es) to use for the field
+        validation_alias: The alias(es) to use to find the field in the validation data
+        serialization_alias: The alias to use as a key when serializing
+        serialization_exclude: Whether to exclude the field when serializing
         frozen: Whether the field is frozen
     """
     return dict_not_none(
@@ -2182,6 +2187,156 @@ def model_schema(
     )
 
 
+class DataclassField(TypedDict, total=False):
+    name: Required[str]
+    schema: Required[CoreSchema]
+    kw_only: bool  # default: True
+    init_only: bool  # default: False
+    validation_alias: Union[str, List[Union[str, int]], List[List[Union[str, int]]]]
+    serialization_alias: str
+    serialization_exclude: bool  # default: False
+
+
+def dataclass_field(
+    name: str,
+    schema: CoreSchema,
+    *,
+    kw_only: bool | None = None,
+    init_only: bool | None = None,
+    validation_alias: str | list[str | int] | list[list[str | int]] | None = None,
+    serialization_alias: str | None = None,
+    serialization_exclude: bool | None = None,
+) -> DataclassField:
+    """
+    Returns a schema for a dataclass field, e.g.:
+
+    ```py
+    from pydantic_core import SchemaValidator, core_schema
+    field = core_schema.dataclass_field(name='a', schema=core_schema.str_schema(), kw_only=False)
+    schema = core_schema.dataclass_args_schema('Foobar', [field])
+    v = SchemaValidator(schema)
+    assert v.validate_python({'a': 'hello'}) == ({'a': 'hello'}, None)
+    ```
+
+    Args:
+        name: The name to use for the argument parameter
+        schema: The schema to use for the argument parameter
+        kw_only: Whether the field can be set with a positional argument as well as a keyword argument
+        init_only: Whether the field should be omitted  from `__dict__` and passed to `__post_init__`
+        validation_alias: The alias(es) to use to find the field in the validation data
+        serialization_alias: The alias to use as a key when serializing
+        serialization_exclude: Whether to exclude the field when serializing
+    """
+    return dict_not_none(
+        name=name,
+        schema=schema,
+        kw_only=kw_only,
+        init_only=init_only,
+        validation_alias=validation_alias,
+        serialization_alias=serialization_alias,
+        serialization_exclude=serialization_exclude,
+    )
+
+
+class DataclassArgsSchema(TypedDict, total=False):
+    type: Required[Literal['dataclass-args']]
+    dataclass_name: Required[str]
+    fields: Required[List[DataclassField]]
+    populate_by_name: bool  # default: False
+    collect_init_only: bool  # default: False
+    ref: str
+    metadata: Any
+    serialization: SerSchema
+
+
+def dataclass_args_schema(
+    dataclass_name: str,
+    fields: list[DataclassField],
+    populate_by_name: bool | None = None,
+    collect_init_only: bool | None = None,
+    ref: str | None = None,
+    metadata: Any = None,
+    serialization: SerSchema | None = None,
+) -> DataclassArgsSchema:
+    """
+    Returns a schema for validating dataclass arguments, e.g.:
+
+    ```py
+    from pydantic_core import SchemaValidator, core_schema
+    field_a = core_schema.dataclass_field(name='a', schema=core_schema.str_schema(), kw_only=False)
+    field_b = core_schema.dataclass_field(name='b', schema=core_schema.bool_schema(), kw_only=False)
+    schema = core_schema.dataclass_args_schema('Foobar', [field_a, field_b])
+    v = SchemaValidator(schema)
+    assert v.validate_python({'a': 'hello', 'b': True}) == ({'a': 'hello', 'b': True}, None)
+    ```
+
+    Args:
+        dataclass_name: The name of the dataclass being validated
+        fields: The fields to use for the dataclass
+        populate_by_name: Whether to populate by name
+        collect_init_only: Whether to collect init only fields into a dict to pass to `__post_init__`
+        ref: See [TODO] for details
+        metadata: See [TODO] for details
+        serialization: Custom serialization schema
+    """
+    return dict_not_none(
+        type='dataclass-args',
+        dataclass_name=dataclass_name,
+        fields=fields,
+        populate_by_name=populate_by_name,
+        collect_init_only=collect_init_only,
+        ref=ref,
+        metadata=metadata,
+        serialization=serialization,
+    )
+
+
+class DataclassSchema(TypedDict, total=False):
+    type: Required[Literal['dataclass']]
+    cls: Required[Type[Any]]
+    schema: Required[CoreSchema]
+    post_init: bool  # default: False
+    strict: bool  # default: False
+    ref: str
+    metadata: Any
+    serialization: SerSchema
+
+
+def dataclass_schema(
+    cls: Type[Any],
+    schema: CoreSchema,
+    *,
+    post_init: bool | None = None,
+    strict: bool | None = None,
+    ref: str | None = None,
+    metadata: Any = None,
+    serialization: SerSchema | None = None,
+) -> DataclassSchema:
+    """
+    Returns a schema for a dataclass. As with `ModelSchema`, this schema can only be used as a field within
+    another schema, not as the root type.
+
+    Args:
+        cls: The dataclass type, used to to perform subclass checks
+        schema: The schema to use for the dataclass fields
+        post_init: Whether to call `__post_init__` after validation
+        strict: Whether to require an exact instance of `cls`
+        ref: See [TODO] for details
+        metadata: See [TODO] for details
+        serialization: Custom serialization schema
+    """
+    return dict_not_none(
+        type='dataclass',
+        cls=cls,
+        schema=schema,
+        post_init=post_init,
+        strict=strict,
+        ref=ref,
+        metadata=metadata,
+        serialization=serialization,
+    )
+
+
 class ArgumentsParameter(TypedDict, total=False):
     name: Required[str]
     schema: Required[CoreSchema]
@@ -2202,6 +2357,9 @@ def arguments_parameter(
     ```py
     from pydantic_core import SchemaValidator, core_schema
     param = core_schema.arguments_parameter(name='a', schema=core_schema.str_schema(), mode='positional_only')
+    schema = core_schema.arguments_schema(param)
+    v = SchemaValidator(schema)
+    assert v.validate_python(('hello',)) == (('hello',), {})
     ```
 
     Args:
@@ -2242,7 +2400,7 @@ def arguments_schema(
     param_b = core_schema.arguments_parameter(name='b', schema=core_schema.bool_schema(), mode='positional_only')
     schema = core_schema.arguments_schema(param_a, param_b)
     v = SchemaValidator(schema)
-    v.validate_python({'__args__': ('hello', True), '__kwargs__': {}})
+    assert v.validate_python(('hello', True)) == (('hello', True), {})
     ```
 
     Args:
@@ -2256,7 +2414,7 @@ def arguments_schema(
     """
     return dict_not_none(
         type='arguments',
-        arguments_schema=arguments,
+        arguments_schema=list(arguments),
         populate_by_name=populate_by_name,
         var_args_schema=var_args_schema,
         var_kwargs_schema=var_kwargs_schema,
@@ -2648,6 +2806,8 @@ CoreSchema = Union[
     LaxOrStrictSchema,
     TypedDictSchema,
     ModelSchema,
+    DataclassArgsSchema,
+    DataclassSchema,
     ArgumentsSchema,
     CallSchema,
     CustomErrorSchema,
@@ -2690,6 +2850,8 @@ CoreSchemaType = Literal[
     'lax-or-strict',
     'typed-dict',
     'model',
+    'dataclass-args',
+    'dataclass',
     'arguments',
     'call',
     'custom-error',
@@ -2781,6 +2943,7 @@ ErrorType = Literal[
     'unexpected_positional_argument',
     'missing_positional_argument',
     'multiple_argument_values',
+    'dataclass_type',
     'url_type',
     'url_parsing',
     'url_syntax_violation',
