@@ -98,6 +98,16 @@ impl<'a> Input<'a> for JsonInput {
         }
     }
 
+    fn validate_dataclass_args(&'a self, dataclass_name: &str) -> ValResult<'a, GenericArguments<'a>> {
+        match self {
+            JsonInput::Object(object) => Ok(JsonArgs::new(None, Some(object)).into()),
+            _ => {
+                let dataclass_name = dataclass_name.to_string();
+                Err(ValError::new(ErrorType::DataclassType { dataclass_name }, self))
+            }
+        }
+    }
+
     fn parse_json(&'a self) -> ValResult<'a, JsonInput> {
         match self {
             JsonInput::String(s) => serde_json::from_str(s.as_str()).map_err(|e| map_json_err(self, e)),
@@ -352,6 +362,12 @@ impl<'a> Input<'a> for String {
         Err(ValError::new(ErrorType::ArgumentsType, self))
     }
 
+    #[cfg_attr(has_no_coverage, no_coverage)]
+    fn validate_dataclass_args(&'a self, dataclass_name: &str) -> ValResult<'a, GenericArguments<'a>> {
+        let dataclass_name = dataclass_name.to_string();
+        Err(ValError::new(ErrorType::DataclassType { dataclass_name }, self))
+    }
+
     fn parse_json(&'a self) -> ValResult<'a, JsonInput> {
         serde_json::from_str(self.as_str()).map_err(|e| map_json_err(self, e))
     }
