@@ -59,12 +59,12 @@ pub struct CustomErrorValidator {
 }
 
 impl BuildValidator for CustomErrorValidator {
-    const EXPECTED_TYPE: &'static str = "custom_error";
+    const EXPECTED_TYPE: &'static str = "custom-error";
 
     fn build(
         schema: &PyDict,
         config: Option<&PyDict>,
-        build_context: &mut BuildContext,
+        build_context: &mut BuildContext<CombinedValidator>,
     ) -> PyResult<CombinedValidator> {
         let custom_error = CustomError::build(schema)?.unwrap();
         let schema: &PyAny = schema.get_as_req(intern!(schema.py(), "schema"))?;
@@ -101,7 +101,7 @@ impl Validator for CustomErrorValidator {
         self.validator.ask(question)
     }
 
-    fn complete(&mut self, build_context: &BuildContext) -> PyResult<()> {
+    fn complete(&mut self, build_context: &BuildContext<CombinedValidator>) -> PyResult<()> {
         self.validator.complete(build_context)
     }
 }
