@@ -907,7 +907,7 @@ class TestBenchmarkUnion:
 
 @pytest.mark.benchmark(group='raise-error')
 def test_dont_raise_error(benchmark):
-    def f(input_value, **kwargs):
+    def f(input_value, info):
         return input_value
 
     v = SchemaValidator({'type': 'function', 'mode': 'plain', 'function': f})
@@ -919,7 +919,7 @@ def test_dont_raise_error(benchmark):
 
 @pytest.mark.benchmark(group='raise-error')
 def test_raise_error_value_error(benchmark):
-    def f(input_value, **kwargs):
+    def f(input_value, info):
         raise ValueError('this is a custom error')
 
     v = SchemaValidator({'type': 'function', 'mode': 'plain', 'function': f})
@@ -936,7 +936,7 @@ def test_raise_error_value_error(benchmark):
 
 @pytest.mark.benchmark(group='raise-error')
 def test_raise_error_custom(benchmark):
-    def f(input_value, **kwargs):
+    def f(input_value, info):
         raise PydanticCustomError('my_error', 'this is a custom error {foo}', {'foo': 'FOOBAR'})
 
     v = SchemaValidator({'type': 'function', 'mode': 'plain', 'function': f})
@@ -1033,10 +1033,7 @@ def test_chain_list(benchmark):
     validator = SchemaValidator(
         {
             'type': 'chain',
-            'steps': [
-                {'type': 'str'},
-                {'type': 'function', 'mode': 'plain', 'function': lambda v, **kwargs: Decimal(v)},
-            ],
+            'steps': [{'type': 'str'}, {'type': 'function', 'mode': 'plain', 'function': lambda v, info: Decimal(v)}],
         }
     )
     assert validator.validate_python('42.42') == Decimal('42.42')
@@ -1047,7 +1044,7 @@ def test_chain_list(benchmark):
 @pytest.mark.benchmark(group='chain')
 def test_chain_function(benchmark):
     validator = SchemaValidator(
-        {'type': 'function', 'mode': 'after', 'schema': {'type': 'str'}, 'function': lambda v, **kwargs: Decimal(v)}
+        {'type': 'function', 'mode': 'after', 'schema': {'type': 'str'}, 'function': lambda v, info: Decimal(v)}
     )
     assert validator.validate_python('42.42') == Decimal('42.42')
 
@@ -1061,8 +1058,8 @@ def test_chain_two_functions(benchmark):
             'type': 'chain',
             'steps': [
                 {'type': 'str'},
-                {'type': 'function', 'mode': 'plain', 'function': lambda v, **kwargs: Decimal(v)},
-                {'type': 'function', 'mode': 'plain', 'function': lambda v, **kwargs: v * 2},
+                {'type': 'function', 'mode': 'plain', 'function': lambda v, info: Decimal(v)},
+                {'type': 'function', 'mode': 'plain', 'function': lambda v, info: v * 2},
             ],
         }
     )
@@ -1080,10 +1077,10 @@ def test_chain_nested_functions(benchmark):
                 'type': 'function',
                 'schema': {'type': 'str'},
                 'mode': 'after',
-                'function': lambda v, **kwargs: Decimal(v),
+                'function': lambda v, info: Decimal(v),
             },
             'mode': 'after',
-            'function': lambda v, **kwargs: v * 2,
+            'function': lambda v, info: v * 2,
         }
     )
     assert validator.validate_python('42.42') == Decimal('84.84')
@@ -1096,7 +1093,7 @@ def validate_yield(iterable, validator):
         yield validator(item)
 
 
-def generator_gen_python(v, *, validator, **_kwargs):
+def generator_gen_python(v, validator, info):
     try:
         iterable = iter(v)
     except TypeError:
