@@ -26,7 +26,7 @@ def test_model_class():
         }
     )
     assert 'expect_fields_set:true' in plain_repr(v)
-    assert repr(v).startswith('SchemaValidator(name="MyModel", validator=Model(\n')
+    assert repr(v).startswith('SchemaValidator(title="MyModel", validator=Model(\n')
     m = v.validate_python({'field_a': 'test', 'field_b': 12})
     assert isinstance(m, MyModel)
     assert m.field_a == 'test'
@@ -34,6 +34,20 @@ def test_model_class():
     assert m.__fields_set__ == {'field_a', 'field_b'}
     assert m.__dict__ == {'field_a': 'test', 'field_b': 12}
 
+    with pytest.raises(ValidationError, match='Input should be an instance of MyModel') as exc_info:
+        v.validate_python({'field_a': 'test', 'field_b': 12}, strict=True)
+
+    # insert_assert(exc_info.value.errors())
+    assert exc_info.value.errors() == [
+        {
+            'type': 'model_class_type',
+            'loc': (),
+            'msg': 'Input should be an instance of MyModel',
+            'input': {'field_a': 'test', 'field_b': 12},
+            'ctx': {'class_name': 'MyModel'},
+        }
+    ]
+
 
 def test_model_class_setattr():
     setattr_calls = []
